@@ -138,7 +138,7 @@ class FinSpaceDataClient(BaseClient):
         self,
         *,
         datasetId: str,
-        destinationTypeParams: "DataViewDestinationTypeParamsTypeDef",
+        destinationTypeParams: DataViewDestinationTypeParamsTypeDef,
         clientToken: str = ...,
         autoUpdate: bool = ...,
         sortColumns: Sequence[str] = ...,
@@ -157,12 +157,12 @@ class FinSpaceDataClient(BaseClient):
         *,
         datasetTitle: str,
         kind: DatasetKindType,
-        permissionGroupParams: "PermissionGroupParamsTypeDef",
+        permissionGroupParams: PermissionGroupParamsTypeDef,
         clientToken: str = ...,
         datasetDescription: str = ...,
-        ownerInfo: "DatasetOwnerInfoTypeDef" = ...,
+        ownerInfo: DatasetOwnerInfoTypeDef = ...,
         alias: str = ...,
-        schemaDefinition: "SchemaUnionTypeDef" = ...
+        schemaDefinition: SchemaUnionTypeDef = ...
     ) -> CreateDatasetResponseTypeDef:
         """
         Creates a new FinSpace Dataset.
@@ -391,7 +391,7 @@ class FinSpaceDataClient(BaseClient):
         clientToken: str = ...,
         datasetDescription: str = ...,
         alias: str = ...,
-        schemaDefinition: "SchemaUnionTypeDef" = ...
+        schemaDefinition: SchemaUnionTypeDef = ...
     ) -> UpdateDatasetResponseTypeDef:
         """
         Updates a FinSpace Dataset.
