@@ -67,7 +67,7 @@ class ListChangesetsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, datasetId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, datasetId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListChangesetsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Paginator.ListChangesets.paginate)
@@ -82,7 +82,7 @@ class ListDataViewsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, datasetId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, datasetId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListDataViewsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Paginator.ListDataViews.paginate)
@@ -97,7 +97,7 @@ class ListDatasetsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListDatasetsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Paginator.ListDatasets.paginate)
@@ -112,7 +112,7 @@ class ListPermissionGroupsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListPermissionGroupsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Paginator.ListPermissionGroups.paginate)
@@ -127,7 +127,7 @@ class ListUsersPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListUsersResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Paginator.ListUsers.paginate)
