@@ -38,77 +38,77 @@ else:
 
 __all__ = (
     "ChangesetErrorInfoTypeDef",
-    "ChangesetSummaryTypeDef",
     "ColumnDefinitionTypeDef",
     "CreateChangesetRequestRequestTypeDef",
-    "CreateChangesetResponseTypeDef",
-    "CreateDataViewRequestRequestTypeDef",
-    "CreateDataViewResponseTypeDef",
-    "CreateDatasetRequestRequestTypeDef",
-    "CreateDatasetResponseTypeDef",
-    "CreatePermissionGroupRequestRequestTypeDef",
-    "CreatePermissionGroupResponseTypeDef",
-    "CreateUserRequestRequestTypeDef",
-    "CreateUserResponseTypeDef",
-    "CredentialsTypeDef",
-    "DataViewDestinationTypeParamsTypeDef",
-    "DataViewErrorInfoTypeDef",
-    "DataViewSummaryTypeDef",
-    "DatasetOwnerInfoTypeDef",
-    "DatasetTypeDef",
-    "DeleteDatasetRequestRequestTypeDef",
-    "DeleteDatasetResponseTypeDef",
-    "DeletePermissionGroupRequestRequestTypeDef",
-    "DeletePermissionGroupResponseTypeDef",
-    "DisableUserRequestRequestTypeDef",
-    "DisableUserResponseTypeDef",
-    "EnableUserRequestRequestTypeDef",
-    "EnableUserResponseTypeDef",
-    "GetChangesetRequestRequestTypeDef",
-    "GetChangesetResponseTypeDef",
-    "GetDataViewRequestRequestTypeDef",
-    "GetDataViewResponseTypeDef",
-    "GetDatasetRequestRequestTypeDef",
-    "GetDatasetResponseTypeDef",
-    "GetProgrammaticAccessCredentialsRequestRequestTypeDef",
-    "GetProgrammaticAccessCredentialsResponseTypeDef",
-    "GetUserRequestRequestTypeDef",
-    "GetUserResponseTypeDef",
-    "GetWorkingLocationRequestRequestTypeDef",
-    "GetWorkingLocationResponseTypeDef",
-    "ListChangesetsRequestListChangesetsPaginateTypeDef",
-    "ListChangesetsRequestRequestTypeDef",
-    "ListChangesetsResponseTypeDef",
-    "ListDataViewsRequestListDataViewsPaginateTypeDef",
-    "ListDataViewsRequestRequestTypeDef",
-    "ListDataViewsResponseTypeDef",
-    "ListDatasetsRequestListDatasetsPaginateTypeDef",
-    "ListDatasetsRequestRequestTypeDef",
-    "ListDatasetsResponseTypeDef",
-    "ListPermissionGroupsRequestListPermissionGroupsPaginateTypeDef",
-    "ListPermissionGroupsRequestRequestTypeDef",
-    "ListPermissionGroupsResponseTypeDef",
-    "ListUsersRequestListUsersPaginateTypeDef",
-    "ListUsersRequestRequestTypeDef",
-    "ListUsersResponseTypeDef",
-    "PaginatorConfigTypeDef",
-    "PermissionGroupParamsTypeDef",
-    "PermissionGroupTypeDef",
-    "ResetUserPasswordRequestRequestTypeDef",
-    "ResetUserPasswordResponseTypeDef",
-    "ResourcePermissionTypeDef",
     "ResponseMetadataTypeDef",
-    "SchemaDefinitionTypeDef",
-    "SchemaUnionTypeDef",
-    "UpdateChangesetRequestRequestTypeDef",
-    "UpdateChangesetResponseTypeDef",
-    "UpdateDatasetRequestRequestTypeDef",
-    "UpdateDatasetResponseTypeDef",
-    "UpdatePermissionGroupRequestRequestTypeDef",
-    "UpdatePermissionGroupResponseTypeDef",
-    "UpdateUserRequestRequestTypeDef",
-    "UpdateUserResponseTypeDef",
+    "DataViewDestinationTypeParamsTypeDef",
+    "DatasetOwnerInfoTypeDef",
+    "CreatePermissionGroupRequestRequestTypeDef",
+    "CreateUserRequestRequestTypeDef",
+    "CredentialsTypeDef",
+    "DataViewErrorInfoTypeDef",
+    "DeleteDatasetRequestRequestTypeDef",
+    "DeletePermissionGroupRequestRequestTypeDef",
+    "DisableUserRequestRequestTypeDef",
+    "EnableUserRequestRequestTypeDef",
+    "GetChangesetRequestRequestTypeDef",
+    "GetDataViewRequestRequestTypeDef",
+    "GetDatasetRequestRequestTypeDef",
+    "GetProgrammaticAccessCredentialsRequestRequestTypeDef",
+    "GetUserRequestRequestTypeDef",
+    "GetWorkingLocationRequestRequestTypeDef",
+    "PaginatorConfigTypeDef",
+    "ListChangesetsRequestRequestTypeDef",
+    "ListDataViewsRequestRequestTypeDef",
+    "ListDatasetsRequestRequestTypeDef",
+    "ListPermissionGroupsRequestRequestTypeDef",
+    "PermissionGroupTypeDef",
+    "ListUsersRequestRequestTypeDef",
     "UserTypeDef",
+    "ResourcePermissionTypeDef",
+    "ResetUserPasswordRequestRequestTypeDef",
+    "UpdateChangesetRequestRequestTypeDef",
+    "UpdatePermissionGroupRequestRequestTypeDef",
+    "UpdateUserRequestRequestTypeDef",
+    "ChangesetSummaryTypeDef",
+    "SchemaDefinitionTypeDef",
+    "CreateChangesetResponseTypeDef",
+    "CreateDataViewResponseTypeDef",
+    "CreateDatasetResponseTypeDef",
+    "CreatePermissionGroupResponseTypeDef",
+    "CreateUserResponseTypeDef",
+    "DeleteDatasetResponseTypeDef",
+    "DeletePermissionGroupResponseTypeDef",
+    "DisableUserResponseTypeDef",
+    "EnableUserResponseTypeDef",
+    "GetChangesetResponseTypeDef",
+    "GetUserResponseTypeDef",
+    "GetWorkingLocationResponseTypeDef",
+    "ResetUserPasswordResponseTypeDef",
+    "UpdateChangesetResponseTypeDef",
+    "UpdateDatasetResponseTypeDef",
+    "UpdatePermissionGroupResponseTypeDef",
+    "UpdateUserResponseTypeDef",
+    "CreateDataViewRequestRequestTypeDef",
+    "GetProgrammaticAccessCredentialsResponseTypeDef",
+    "DataViewSummaryTypeDef",
+    "GetDataViewResponseTypeDef",
+    "ListChangesetsRequestListChangesetsPaginateTypeDef",
+    "ListDataViewsRequestListDataViewsPaginateTypeDef",
+    "ListDatasetsRequestListDatasetsPaginateTypeDef",
+    "ListPermissionGroupsRequestListPermissionGroupsPaginateTypeDef",
+    "ListUsersRequestListUsersPaginateTypeDef",
+    "ListPermissionGroupsResponseTypeDef",
+    "ListUsersResponseTypeDef",
+    "PermissionGroupParamsTypeDef",
+    "ListChangesetsResponseTypeDef",
+    "SchemaUnionTypeDef",
+    "ListDataViewsResponseTypeDef",
+    "CreateDatasetRequestRequestTypeDef",
+    "DatasetTypeDef",
+    "GetDatasetResponseTypeDef",
+    "UpdateDatasetRequestRequestTypeDef",
+    "ListDatasetsResponseTypeDef",
 )
 
 ChangesetErrorInfoTypeDef = TypedDict(
@@ -120,26 +120,6 @@ ChangesetErrorInfoTypeDef = TypedDict(
     total=False,
 )
 
-ChangesetSummaryTypeDef = TypedDict(
-    "ChangesetSummaryTypeDef",
-    {
-        "changesetId": str,
-        "changesetArn": str,
-        "datasetId": str,
-        "changeType": ChangeTypeType,
-        "sourceParams": Dict[str, str],
-        "formatParams": Dict[str, str],
-        "createTime": int,
-        "status": IngestionStatusType,
-        "errorInfo": "ChangesetErrorInfoTypeDef",
-        "activeUntilTimestamp": int,
-        "activeFromTimestamp": int,
-        "updatesChangesetId": str,
-        "updatedByChangesetId": str,
-    },
-    total=False,
-)
-
 ColumnDefinitionTypeDef = TypedDict(
     "ColumnDefinitionTypeDef",
     {
@@ -174,85 +154,49 @@ class CreateChangesetRequestRequestTypeDef(
     pass
 
 
-CreateChangesetResponseTypeDef = TypedDict(
-    "CreateChangesetResponseTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "datasetId": str,
-        "changesetId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
-_RequiredCreateDataViewRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateDataViewRequestRequestTypeDef",
+_RequiredDataViewDestinationTypeParamsTypeDef = TypedDict(
+    "_RequiredDataViewDestinationTypeParamsTypeDef",
     {
-        "datasetId": str,
-        "destinationTypeParams": "DataViewDestinationTypeParamsTypeDef",
+        "destinationType": str,
     },
 )
-_OptionalCreateDataViewRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateDataViewRequestRequestTypeDef",
+_OptionalDataViewDestinationTypeParamsTypeDef = TypedDict(
+    "_OptionalDataViewDestinationTypeParamsTypeDef",
     {
-        "clientToken": str,
-        "autoUpdate": bool,
-        "sortColumns": Sequence[str],
-        "partitionColumns": Sequence[str],
-        "asOfTimestamp": int,
+        "s3DestinationExportFileFormat": ExportFileFormatType,
+        "s3DestinationExportFileFormatOptions": Mapping[str, str],
     },
     total=False,
 )
 
 
-class CreateDataViewRequestRequestTypeDef(
-    _RequiredCreateDataViewRequestRequestTypeDef, _OptionalCreateDataViewRequestRequestTypeDef
+class DataViewDestinationTypeParamsTypeDef(
+    _RequiredDataViewDestinationTypeParamsTypeDef, _OptionalDataViewDestinationTypeParamsTypeDef
 ):
     pass
 
 
-CreateDataViewResponseTypeDef = TypedDict(
-    "CreateDataViewResponseTypeDef",
+DatasetOwnerInfoTypeDef = TypedDict(
+    "DatasetOwnerInfoTypeDef",
     {
-        "datasetId": str,
-        "dataViewId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredCreateDatasetRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateDatasetRequestRequestTypeDef",
-    {
-        "datasetTitle": str,
-        "kind": DatasetKindType,
-        "permissionGroupParams": "PermissionGroupParamsTypeDef",
-    },
-)
-_OptionalCreateDatasetRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateDatasetRequestRequestTypeDef",
-    {
-        "clientToken": str,
-        "datasetDescription": str,
-        "ownerInfo": "DatasetOwnerInfoTypeDef",
-        "alias": str,
-        "schemaDefinition": "SchemaUnionTypeDef",
+        "name": str,
+        "phoneNumber": str,
+        "email": str,
     },
     total=False,
 )
 
-
-class CreateDatasetRequestRequestTypeDef(
-    _RequiredCreateDatasetRequestRequestTypeDef, _OptionalCreateDatasetRequestRequestTypeDef
-):
-    pass
-
-
-CreateDatasetResponseTypeDef = TypedDict(
-    "CreateDatasetResponseTypeDef",
-    {
-        "datasetId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredCreatePermissionGroupRequestRequestTypeDef = TypedDict(
     "_RequiredCreatePermissionGroupRequestRequestTypeDef",
     {
@@ -277,14 +221,6 @@ class CreatePermissionGroupRequestRequestTypeDef(
     pass
 
 
-CreatePermissionGroupResponseTypeDef = TypedDict(
-    "CreatePermissionGroupResponseTypeDef",
-    {
-        "permissionGroupId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredCreateUserRequestRequestTypeDef = TypedDict(
     "_RequiredCreateUserRequestRequestTypeDef",
     {
@@ -311,14 +247,6 @@ class CreateUserRequestRequestTypeDef(
     pass
 
 
-CreateUserResponseTypeDef = TypedDict(
-    "CreateUserResponseTypeDef",
-    {
-        "userId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 CredentialsTypeDef = TypedDict(
     "CredentialsTypeDef",
     {
@@ -329,28 +257,6 @@ CredentialsTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredDataViewDestinationTypeParamsTypeDef = TypedDict(
-    "_RequiredDataViewDestinationTypeParamsTypeDef",
-    {
-        "destinationType": str,
-    },
-)
-_OptionalDataViewDestinationTypeParamsTypeDef = TypedDict(
-    "_OptionalDataViewDestinationTypeParamsTypeDef",
-    {
-        "s3DestinationExportFileFormat": ExportFileFormatType,
-        "s3DestinationExportFileFormatOptions": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class DataViewDestinationTypeParamsTypeDef(
-    _RequiredDataViewDestinationTypeParamsTypeDef, _OptionalDataViewDestinationTypeParamsTypeDef
-):
-    pass
-
-
 DataViewErrorInfoTypeDef = TypedDict(
     "DataViewErrorInfoTypeDef",
     {
@@ -360,52 +266,6 @@ DataViewErrorInfoTypeDef = TypedDict(
     total=False,
 )
 
-DataViewSummaryTypeDef = TypedDict(
-    "DataViewSummaryTypeDef",
-    {
-        "dataViewId": str,
-        "dataViewArn": str,
-        "datasetId": str,
-        "asOfTimestamp": int,
-        "partitionColumns": List[str],
-        "sortColumns": List[str],
-        "status": DataViewStatusType,
-        "errorInfo": "DataViewErrorInfoTypeDef",
-        "destinationTypeProperties": "DataViewDestinationTypeParamsTypeDef",
-        "autoUpdate": bool,
-        "createTime": int,
-        "lastModifiedTime": int,
-    },
-    total=False,
-)
-
-DatasetOwnerInfoTypeDef = TypedDict(
-    "DatasetOwnerInfoTypeDef",
-    {
-        "name": str,
-        "phoneNumber": str,
-        "email": str,
-    },
-    total=False,
-)
-
-DatasetTypeDef = TypedDict(
-    "DatasetTypeDef",
-    {
-        "datasetId": str,
-        "datasetArn": str,
-        "datasetTitle": str,
-        "kind": DatasetKindType,
-        "datasetDescription": str,
-        "ownerInfo": "DatasetOwnerInfoTypeDef",
-        "createTime": int,
-        "lastModifiedTime": int,
-        "schemaDefinition": "SchemaUnionTypeDef",
-        "alias": str,
-    },
-    total=False,
-)
-
 _RequiredDeleteDatasetRequestRequestTypeDef = TypedDict(
     "_RequiredDeleteDatasetRequestRequestTypeDef",
     {
@@ -427,14 +287,6 @@ class DeleteDatasetRequestRequestTypeDef(
     pass
 
 
-DeleteDatasetResponseTypeDef = TypedDict(
-    "DeleteDatasetResponseTypeDef",
-    {
-        "datasetId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredDeletePermissionGroupRequestRequestTypeDef = TypedDict(
     "_RequiredDeletePermissionGroupRequestRequestTypeDef",
     {
@@ -457,14 +309,6 @@ class DeletePermissionGroupRequestRequestTypeDef(
     pass
 
 
-DeletePermissionGroupResponseTypeDef = TypedDict(
-    "DeletePermissionGroupResponseTypeDef",
-    {
-        "permissionGroupId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredDisableUserRequestRequestTypeDef = TypedDict(
     "_RequiredDisableUserRequestRequestTypeDef",
     {
@@ -486,14 +330,6 @@ class DisableUserRequestRequestTypeDef(
     pass
 
 
-DisableUserResponseTypeDef = TypedDict(
-    "DisableUserResponseTypeDef",
-    {
-        "userId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredEnableUserRequestRequestTypeDef = TypedDict(
     "_RequiredEnableUserRequestRequestTypeDef",
     {
@@ -515,14 +351,6 @@ class EnableUserRequestRequestTypeDef(
     pass
 
 
-EnableUserResponseTypeDef = TypedDict(
-    "EnableUserResponseTypeDef",
-    {
-        "userId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 GetChangesetRequestRequestTypeDef = TypedDict(
     "GetChangesetRequestRequestTypeDef",
     {
@@ -531,26 +359,6 @@ GetChangesetRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetChangesetResponseTypeDef = TypedDict(
-    "GetChangesetResponseTypeDef",
-    {
-        "changesetId": str,
-        "changesetArn": str,
-        "datasetId": str,
-        "changeType": ChangeTypeType,
-        "sourceParams": Dict[str, str],
-        "formatParams": Dict[str, str],
-        "createTime": int,
-        "status": IngestionStatusType,
-        "errorInfo": "ChangesetErrorInfoTypeDef",
-        "activeUntilTimestamp": int,
-        "activeFromTimestamp": int,
-        "updatesChangesetId": str,
-        "updatedByChangesetId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 GetDataViewRequestRequestTypeDef = TypedDict(
     "GetDataViewRequestRequestTypeDef",
     {
@@ -559,25 +367,6 @@ GetDataViewRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetDataViewResponseTypeDef = TypedDict(
-    "GetDataViewResponseTypeDef",
-    {
-        "autoUpdate": bool,
-        "partitionColumns": List[str],
-        "datasetId": str,
-        "asOfTimestamp": int,
-        "errorInfo": "DataViewErrorInfoTypeDef",
-        "lastModifiedTime": int,
-        "createTime": int,
-        "sortColumns": List[str],
-        "dataViewId": str,
-        "dataViewArn": str,
-        "destinationTypeParams": "DataViewDestinationTypeParamsTypeDef",
-        "status": DataViewStatusType,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 GetDatasetRequestRequestTypeDef = TypedDict(
     "GetDatasetRequestRequestTypeDef",
     {
@@ -585,23 +374,6 @@ GetDatasetRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetDatasetResponseTypeDef = TypedDict(
-    "GetDatasetResponseTypeDef",
-    {
-        "datasetId": str,
-        "datasetArn": str,
-        "datasetTitle": str,
-        "kind": DatasetKindType,
-        "datasetDescription": str,
-        "createTime": int,
-        "lastModifiedTime": int,
-        "schemaDefinition": "SchemaUnionTypeDef",
-        "alias": str,
-        "status": DatasetStatusType,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredGetProgrammaticAccessCredentialsRequestRequestTypeDef = TypedDict(
     "_RequiredGetProgrammaticAccessCredentialsRequestRequestTypeDef",
     {
@@ -624,15 +396,6 @@ class GetProgrammaticAccessCredentialsRequestRequestTypeDef(
     pass
 
 
-GetProgrammaticAccessCredentialsResponseTypeDef = TypedDict(
-    "GetProgrammaticAccessCredentialsResponseTypeDef",
-    {
-        "credentials": "CredentialsTypeDef",
-        "durationInMinutes": int,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 GetUserRequestRequestTypeDef = TypedDict(
     "GetUserRequestRequestTypeDef",
     {
@@ -640,26 +403,6 @@ GetUserRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetUserResponseTypeDef = TypedDict(
-    "GetUserResponseTypeDef",
-    {
-        "userId": str,
-        "status": UserStatusType,
-        "firstName": str,
-        "lastName": str,
-        "emailAddress": str,
-        "type": UserTypeType,
-        "apiAccess": ApiAccessType,
-        "apiAccessPrincipalArn": str,
-        "createTime": int,
-        "lastEnabledTime": int,
-        "lastDisabledTime": int,
-        "lastModifiedTime": int,
-        "lastLoginTime": int,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 GetWorkingLocationRequestRequestTypeDef = TypedDict(
     "GetWorkingLocationRequestRequestTypeDef",
     {
@@ -668,38 +411,16 @@ GetWorkingLocationRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-GetWorkingLocationResponseTypeDef = TypedDict(
-    "GetWorkingLocationResponseTypeDef",
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
     {
-        "s3Uri": str,
-        "s3Path": str,
-        "s3Bucket": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredListChangesetsRequestListChangesetsPaginateTypeDef = TypedDict(
-    "_RequiredListChangesetsRequestListChangesetsPaginateTypeDef",
-    {
-        "datasetId": str,
-    },
-)
-_OptionalListChangesetsRequestListChangesetsPaginateTypeDef = TypedDict(
-    "_OptionalListChangesetsRequestListChangesetsPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
     total=False,
 )
 
-
-class ListChangesetsRequestListChangesetsPaginateTypeDef(
-    _RequiredListChangesetsRequestListChangesetsPaginateTypeDef,
-    _OptionalListChangesetsRequestListChangesetsPaginateTypeDef,
-):
-    pass
-
-
 _RequiredListChangesetsRequestRequestTypeDef = TypedDict(
     "_RequiredListChangesetsRequestRequestTypeDef",
     {
@@ -722,37 +443,6 @@ class ListChangesetsRequestRequestTypeDef(
     pass
 
 
-ListChangesetsResponseTypeDef = TypedDict(
-    "ListChangesetsResponseTypeDef",
-    {
-        "changesets": List["ChangesetSummaryTypeDef"],
-        "nextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredListDataViewsRequestListDataViewsPaginateTypeDef = TypedDict(
-    "_RequiredListDataViewsRequestListDataViewsPaginateTypeDef",
-    {
-        "datasetId": str,
-    },
-)
-_OptionalListDataViewsRequestListDataViewsPaginateTypeDef = TypedDict(
-    "_OptionalListDataViewsRequestListDataViewsPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class ListDataViewsRequestListDataViewsPaginateTypeDef(
-    _RequiredListDataViewsRequestListDataViewsPaginateTypeDef,
-    _OptionalListDataViewsRequestListDataViewsPaginateTypeDef,
-):
-    pass
-
-
 _RequiredListDataViewsRequestRequestTypeDef = TypedDict(
     "_RequiredListDataViewsRequestRequestTypeDef",
     {
@@ -775,23 +465,6 @@ class ListDataViewsRequestRequestTypeDef(
     pass
 
 
-ListDataViewsResponseTypeDef = TypedDict(
-    "ListDataViewsResponseTypeDef",
-    {
-        "nextToken": str,
-        "dataViews": List["DataViewSummaryTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListDatasetsRequestListDatasetsPaginateTypeDef = TypedDict(
-    "ListDatasetsRequestListDatasetsPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
 ListDatasetsRequestRequestTypeDef = TypedDict(
     "ListDatasetsRequestRequestTypeDef",
     {
@@ -801,23 +474,6 @@ ListDatasetsRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListDatasetsResponseTypeDef = TypedDict(
-    "ListDatasetsResponseTypeDef",
-    {
-        "datasets": List["DatasetTypeDef"],
-        "nextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListPermissionGroupsRequestListPermissionGroupsPaginateTypeDef = TypedDict(
-    "ListPermissionGroupsRequestListPermissionGroupsPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
 _RequiredListPermissionGroupsRequestRequestTypeDef = TypedDict(
     "_RequiredListPermissionGroupsRequestRequestTypeDef",
     {
@@ -840,19 +496,15 @@ class ListPermissionGroupsRequestRequestTypeDef(
     pass
 
 
-ListPermissionGroupsResponseTypeDef = TypedDict(
-    "ListPermissionGroupsResponseTypeDef",
+PermissionGroupTypeDef = TypedDict(
+    "PermissionGroupTypeDef",
     {
-        "permissionGroups": List["PermissionGroupTypeDef"],
-        "nextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListUsersRequestListUsersPaginateTypeDef = TypedDict(
-    "ListUsersRequestListUsersPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
+        "permissionGroupId": str,
+        "name": str,
+        "description": str,
+        "applicationPermissions": List[ApplicationPermissionType],
+        "createTime": int,
+        "lastModifiedTime": int,
     },
     total=False,
 )
@@ -878,43 +530,30 @@ class ListUsersRequestRequestTypeDef(
     pass
 
 
-ListUsersResponseTypeDef = TypedDict(
-    "ListUsersResponseTypeDef",
+UserTypeDef = TypedDict(
+    "UserTypeDef",
     {
-        "users": List["UserTypeDef"],
-        "nextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef",
-    {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
-    },
-    total=False,
-)
-
-PermissionGroupParamsTypeDef = TypedDict(
-    "PermissionGroupParamsTypeDef",
-    {
-        "permissionGroupId": str,
-        "datasetPermissions": Sequence["ResourcePermissionTypeDef"],
-    },
-    total=False,
-)
-
-PermissionGroupTypeDef = TypedDict(
-    "PermissionGroupTypeDef",
-    {
-        "permissionGroupId": str,
-        "name": str,
-        "description": str,
-        "applicationPermissions": List[ApplicationPermissionType],
+        "userId": str,
+        "status": UserStatusType,
+        "firstName": str,
+        "lastName": str,
+        "emailAddress": str,
+        "type": UserTypeType,
+        "apiAccess": ApiAccessType,
+        "apiAccessPrincipalArn": str,
         "createTime": int,
+        "lastEnabledTime": int,
+        "lastDisabledTime": int,
         "lastModifiedTime": int,
+        "lastLoginTime": int,
+    },
+    total=False,
+)
+
+ResourcePermissionTypeDef = TypedDict(
+    "ResourcePermissionTypeDef",
+    {
+        "permission": str,
     },
     total=False,
 )
@@ -940,51 +579,6 @@ class ResetUserPasswordRequestRequestTypeDef(
     pass
 
 
-ResetUserPasswordResponseTypeDef = TypedDict(
-    "ResetUserPasswordResponseTypeDef",
-    {
-        "userId": str,
-        "temporaryPassword": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ResourcePermissionTypeDef = TypedDict(
-    "ResourcePermissionTypeDef",
-    {
-        "permission": str,
-    },
-    total=False,
-)
-
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
-    },
-)
-
-SchemaDefinitionTypeDef = TypedDict(
-    "SchemaDefinitionTypeDef",
-    {
-        "columns": Sequence["ColumnDefinitionTypeDef"],
-        "primaryKeyColumns": Sequence[str],
-    },
-    total=False,
-)
-
-SchemaUnionTypeDef = TypedDict(
-    "SchemaUnionTypeDef",
-    {
-        "tabularSchemaConfig": "SchemaDefinitionTypeDef",
-    },
-    total=False,
-)
-
 _RequiredUpdateChangesetRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateChangesetRequestRequestTypeDef",
     {
@@ -1009,49 +603,6 @@ class UpdateChangesetRequestRequestTypeDef(
     pass
 
 
-UpdateChangesetResponseTypeDef = TypedDict(
-    "UpdateChangesetResponseTypeDef",
-    {
-        "changesetId": str,
-        "datasetId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredUpdateDatasetRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateDatasetRequestRequestTypeDef",
-    {
-        "datasetId": str,
-        "datasetTitle": str,
-        "kind": DatasetKindType,
-    },
-)
-_OptionalUpdateDatasetRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateDatasetRequestRequestTypeDef",
-    {
-        "clientToken": str,
-        "datasetDescription": str,
-        "alias": str,
-        "schemaDefinition": "SchemaUnionTypeDef",
-    },
-    total=False,
-)
-
-
-class UpdateDatasetRequestRequestTypeDef(
-    _RequiredUpdateDatasetRequestRequestTypeDef, _OptionalUpdateDatasetRequestRequestTypeDef
-):
-    pass
-
-
-UpdateDatasetResponseTypeDef = TypedDict(
-    "UpdateDatasetResponseTypeDef",
-    {
-        "datasetId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredUpdatePermissionGroupRequestRequestTypeDef = TypedDict(
     "_RequiredUpdatePermissionGroupRequestRequestTypeDef",
     {
@@ -1077,14 +628,6 @@ class UpdatePermissionGroupRequestRequestTypeDef(
     pass
 
 
-UpdatePermissionGroupResponseTypeDef = TypedDict(
-    "UpdatePermissionGroupResponseTypeDef",
-    {
-        "permissionGroupId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredUpdateUserRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateUserRequestRequestTypeDef",
     {
@@ -1111,16 +654,131 @@ class UpdateUserRequestRequestTypeDef(
     pass
 
 
-UpdateUserResponseTypeDef = TypedDict(
-    "UpdateUserResponseTypeDef",
+ChangesetSummaryTypeDef = TypedDict(
+    "ChangesetSummaryTypeDef",
     {
-        "userId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "changesetId": str,
+        "changesetArn": str,
+        "datasetId": str,
+        "changeType": ChangeTypeType,
+        "sourceParams": Dict[str, str],
+        "formatParams": Dict[str, str],
+        "createTime": int,
+        "status": IngestionStatusType,
+        "errorInfo": ChangesetErrorInfoTypeDef,
+        "activeUntilTimestamp": int,
+        "activeFromTimestamp": int,
+        "updatesChangesetId": str,
+        "updatedByChangesetId": str,
+    },
+    total=False,
+)
+
+SchemaDefinitionTypeDef = TypedDict(
+    "SchemaDefinitionTypeDef",
+    {
+        "columns": Sequence[ColumnDefinitionTypeDef],
+        "primaryKeyColumns": Sequence[str],
+    },
+    total=False,
+)
+
+CreateChangesetResponseTypeDef = TypedDict(
+    "CreateChangesetResponseTypeDef",
+    {
+        "datasetId": str,
+        "changesetId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
 
-UserTypeDef = TypedDict(
-    "UserTypeDef",
+CreateDataViewResponseTypeDef = TypedDict(
+    "CreateDataViewResponseTypeDef",
+    {
+        "datasetId": str,
+        "dataViewId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateDatasetResponseTypeDef = TypedDict(
+    "CreateDatasetResponseTypeDef",
+    {
+        "datasetId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreatePermissionGroupResponseTypeDef = TypedDict(
+    "CreatePermissionGroupResponseTypeDef",
+    {
+        "permissionGroupId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateUserResponseTypeDef = TypedDict(
+    "CreateUserResponseTypeDef",
+    {
+        "userId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DeleteDatasetResponseTypeDef = TypedDict(
+    "DeleteDatasetResponseTypeDef",
+    {
+        "datasetId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DeletePermissionGroupResponseTypeDef = TypedDict(
+    "DeletePermissionGroupResponseTypeDef",
+    {
+        "permissionGroupId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DisableUserResponseTypeDef = TypedDict(
+    "DisableUserResponseTypeDef",
+    {
+        "userId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+EnableUserResponseTypeDef = TypedDict(
+    "EnableUserResponseTypeDef",
+    {
+        "userId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetChangesetResponseTypeDef = TypedDict(
+    "GetChangesetResponseTypeDef",
+    {
+        "changesetId": str,
+        "changesetArn": str,
+        "datasetId": str,
+        "changeType": ChangeTypeType,
+        "sourceParams": Dict[str, str],
+        "formatParams": Dict[str, str],
+        "createTime": int,
+        "status": IngestionStatusType,
+        "errorInfo": ChangesetErrorInfoTypeDef,
+        "activeUntilTimestamp": int,
+        "activeFromTimestamp": int,
+        "updatesChangesetId": str,
+        "updatedByChangesetId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetUserResponseTypeDef = TypedDict(
+    "GetUserResponseTypeDef",
     {
         "userId": str,
         "status": UserStatusType,
@@ -1135,6 +793,348 @@ UserTypeDef = TypedDict(
         "lastDisabledTime": int,
         "lastModifiedTime": int,
         "lastLoginTime": int,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetWorkingLocationResponseTypeDef = TypedDict(
+    "GetWorkingLocationResponseTypeDef",
+    {
+        "s3Uri": str,
+        "s3Path": str,
+        "s3Bucket": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ResetUserPasswordResponseTypeDef = TypedDict(
+    "ResetUserPasswordResponseTypeDef",
+    {
+        "userId": str,
+        "temporaryPassword": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateChangesetResponseTypeDef = TypedDict(
+    "UpdateChangesetResponseTypeDef",
+    {
+        "changesetId": str,
+        "datasetId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateDatasetResponseTypeDef = TypedDict(
+    "UpdateDatasetResponseTypeDef",
+    {
+        "datasetId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdatePermissionGroupResponseTypeDef = TypedDict(
+    "UpdatePermissionGroupResponseTypeDef",
+    {
+        "permissionGroupId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateUserResponseTypeDef = TypedDict(
+    "UpdateUserResponseTypeDef",
+    {
+        "userId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredCreateDataViewRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateDataViewRequestRequestTypeDef",
+    {
+        "datasetId": str,
+        "destinationTypeParams": DataViewDestinationTypeParamsTypeDef,
+    },
+)
+_OptionalCreateDataViewRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateDataViewRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "autoUpdate": bool,
+        "sortColumns": Sequence[str],
+        "partitionColumns": Sequence[str],
+        "asOfTimestamp": int,
     },
     total=False,
 )
+
+
+class CreateDataViewRequestRequestTypeDef(
+    _RequiredCreateDataViewRequestRequestTypeDef, _OptionalCreateDataViewRequestRequestTypeDef
+):
+    pass
+
+
+GetProgrammaticAccessCredentialsResponseTypeDef = TypedDict(
+    "GetProgrammaticAccessCredentialsResponseTypeDef",
+    {
+        "credentials": CredentialsTypeDef,
+        "durationInMinutes": int,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DataViewSummaryTypeDef = TypedDict(
+    "DataViewSummaryTypeDef",
+    {
+        "dataViewId": str,
+        "dataViewArn": str,
+        "datasetId": str,
+        "asOfTimestamp": int,
+        "partitionColumns": List[str],
+        "sortColumns": List[str],
+        "status": DataViewStatusType,
+        "errorInfo": DataViewErrorInfoTypeDef,
+        "destinationTypeProperties": DataViewDestinationTypeParamsTypeDef,
+        "autoUpdate": bool,
+        "createTime": int,
+        "lastModifiedTime": int,
+    },
+    total=False,
+)
+
+GetDataViewResponseTypeDef = TypedDict(
+    "GetDataViewResponseTypeDef",
+    {
+        "autoUpdate": bool,
+        "partitionColumns": List[str],
+        "datasetId": str,
+        "asOfTimestamp": int,
+        "errorInfo": DataViewErrorInfoTypeDef,
+        "lastModifiedTime": int,
+        "createTime": int,
+        "sortColumns": List[str],
+        "dataViewId": str,
+        "dataViewArn": str,
+        "destinationTypeParams": DataViewDestinationTypeParamsTypeDef,
+        "status": DataViewStatusType,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredListChangesetsRequestListChangesetsPaginateTypeDef = TypedDict(
+    "_RequiredListChangesetsRequestListChangesetsPaginateTypeDef",
+    {
+        "datasetId": str,
+    },
+)
+_OptionalListChangesetsRequestListChangesetsPaginateTypeDef = TypedDict(
+    "_OptionalListChangesetsRequestListChangesetsPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListChangesetsRequestListChangesetsPaginateTypeDef(
+    _RequiredListChangesetsRequestListChangesetsPaginateTypeDef,
+    _OptionalListChangesetsRequestListChangesetsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListDataViewsRequestListDataViewsPaginateTypeDef = TypedDict(
+    "_RequiredListDataViewsRequestListDataViewsPaginateTypeDef",
+    {
+        "datasetId": str,
+    },
+)
+_OptionalListDataViewsRequestListDataViewsPaginateTypeDef = TypedDict(
+    "_OptionalListDataViewsRequestListDataViewsPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListDataViewsRequestListDataViewsPaginateTypeDef(
+    _RequiredListDataViewsRequestListDataViewsPaginateTypeDef,
+    _OptionalListDataViewsRequestListDataViewsPaginateTypeDef,
+):
+    pass
+
+
+ListDatasetsRequestListDatasetsPaginateTypeDef = TypedDict(
+    "ListDatasetsRequestListDatasetsPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+ListPermissionGroupsRequestListPermissionGroupsPaginateTypeDef = TypedDict(
+    "ListPermissionGroupsRequestListPermissionGroupsPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+ListUsersRequestListUsersPaginateTypeDef = TypedDict(
+    "ListUsersRequestListUsersPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+ListPermissionGroupsResponseTypeDef = TypedDict(
+    "ListPermissionGroupsResponseTypeDef",
+    {
+        "permissionGroups": List[PermissionGroupTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListUsersResponseTypeDef = TypedDict(
+    "ListUsersResponseTypeDef",
+    {
+        "users": List[UserTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+PermissionGroupParamsTypeDef = TypedDict(
+    "PermissionGroupParamsTypeDef",
+    {
+        "permissionGroupId": str,
+        "datasetPermissions": Sequence[ResourcePermissionTypeDef],
+    },
+    total=False,
+)
+
+ListChangesetsResponseTypeDef = TypedDict(
+    "ListChangesetsResponseTypeDef",
+    {
+        "changesets": List[ChangesetSummaryTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+SchemaUnionTypeDef = TypedDict(
+    "SchemaUnionTypeDef",
+    {
+        "tabularSchemaConfig": SchemaDefinitionTypeDef,
+    },
+    total=False,
+)
+
+ListDataViewsResponseTypeDef = TypedDict(
+    "ListDataViewsResponseTypeDef",
+    {
+        "nextToken": str,
+        "dataViews": List[DataViewSummaryTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredCreateDatasetRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateDatasetRequestRequestTypeDef",
+    {
+        "datasetTitle": str,
+        "kind": DatasetKindType,
+        "permissionGroupParams": PermissionGroupParamsTypeDef,
+    },
+)
+_OptionalCreateDatasetRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateDatasetRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "datasetDescription": str,
+        "ownerInfo": DatasetOwnerInfoTypeDef,
+        "alias": str,
+        "schemaDefinition": SchemaUnionTypeDef,
+    },
+    total=False,
+)
+
+
+class CreateDatasetRequestRequestTypeDef(
+    _RequiredCreateDatasetRequestRequestTypeDef, _OptionalCreateDatasetRequestRequestTypeDef
+):
+    pass
+
+
+DatasetTypeDef = TypedDict(
+    "DatasetTypeDef",
+    {
+        "datasetId": str,
+        "datasetArn": str,
+        "datasetTitle": str,
+        "kind": DatasetKindType,
+        "datasetDescription": str,
+        "ownerInfo": DatasetOwnerInfoTypeDef,
+        "createTime": int,
+        "lastModifiedTime": int,
+        "schemaDefinition": SchemaUnionTypeDef,
+        "alias": str,
+    },
+    total=False,
+)
+
+GetDatasetResponseTypeDef = TypedDict(
+    "GetDatasetResponseTypeDef",
+    {
+        "datasetId": str,
+        "datasetArn": str,
+        "datasetTitle": str,
+        "kind": DatasetKindType,
+        "datasetDescription": str,
+        "createTime": int,
+        "lastModifiedTime": int,
+        "schemaDefinition": SchemaUnionTypeDef,
+        "alias": str,
+        "status": DatasetStatusType,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredUpdateDatasetRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateDatasetRequestRequestTypeDef",
+    {
+        "datasetId": str,
+        "datasetTitle": str,
+        "kind": DatasetKindType,
+    },
+)
+_OptionalUpdateDatasetRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateDatasetRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "datasetDescription": str,
+        "alias": str,
+        "schemaDefinition": SchemaUnionTypeDef,
+    },
+    total=False,
+)
+
+
+class UpdateDatasetRequestRequestTypeDef(
+    _RequiredUpdateDatasetRequestRequestTypeDef, _OptionalUpdateDatasetRequestRequestTypeDef
+):
+    pass
+
+
+ListDatasetsResponseTypeDef = TypedDict(
+    "ListDatasetsResponseTypeDef",
+    {
+        "datasets": List[DatasetTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
